@@ -30,6 +30,8 @@ class CloudFrontResponse(BaseResponse):
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.create_invalidation()
+        if request.method == "GET":
+            return self.list_invalidations()
 
     def tags(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
@@ -83,9 +85,9 @@ class CloudFrontResponse(BaseResponse):
         if_match = headers["If-Match"]
 
         dist, location, e_tag = self.backend.update_distribution(
-            DistributionConfig=distribution_config,
-            Id=dist_id,
-            IfMatch=if_match,
+            dist_config=distribution_config,
+            _id=dist_id,
+            if_match=if_match,
         )
         template = self.response_template(UPDATE_DISTRIBUTION_TEMPLATE)
         response = template.render(distribution=dist, xmlns=XMLNS)
@@ -104,6 +106,14 @@ class CloudFrontResponse(BaseResponse):
 
         return 200, {"Location": invalidation.location}, response
 
+    def list_invalidations(self):
+        dist_id = self.path.split("/")[-2]
+        invalidations = self.backend.list_invalidations(dist_id)
+        template = self.response_template(INVALIDATIONS_TEMPLATE)
+        response = template.render(invalidations=invalidations, xmlns=XMLNS)
+
+        return 200, {}, response
+
     def list_tags_for_resource(self):
         resource = unquote(self._get_param("Resource"))
         tags = self.backend.list_tags_for_resource(resource=resource)["Tags"]
@@ -590,6 +600,24 @@ CREATE_INVALIDATION_TEMPLATE = """<?xml version="1.0"?>
 </Invalidation>
 """
 
+INVALIDATIONS_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
+<InvalidationList>
+   <IsTruncated>false</IsTruncated>
+   <Items>
+      {% for invalidation in invalidations %}
+      <InvalidationSummary>
+         <CreateTime>{{ invalidation.create_time }}</CreateTime>
+         <Id>{{ invalidation.invalidation_id }}</Id>
+         <Status>{{ invalidation.status }}</Status>
+      </InvalidationSummary>
+      {% endfor %}
+   </Items>
+   <Marker></Marker>
+   <MaxItems>100</MaxItems>
+   <Quantity>{{ invalidations|length }}</Quantity>
+</InvalidationList>
+"""
+
 TAGS_TEMPLATE = """<?xml version="1.0"?>
 <Tags>
   <Items>
