@@ -8,6 +8,4 @@ class DataSyncClientError(JsonRESTError):
 class InvalidRequestException(DataSyncClientError):
     def __init__(self, msg=None):
         self.code = 400
-        super(InvalidRequestException, self).__init__(
-            "InvalidRequestException", msg or "The request is not valid."
-        )
+        super().__init__("InvalidRequestException", msg or "The request is not valid.")
