@@ -259,11 +259,15 @@ class InvalidInstanceIdError(EC2ClientError):
 
 
 class InvalidInstanceTypeError(EC2ClientError):
-    def __init__(self, instance_type):
-        super().__init__(
-            "InvalidInstanceType.NotFound",
-            "The instance type '{0}' does not exist".format(instance_type),
-        )
+    def __init__(self, instance_type, error_type="InvalidInstanceType.NotFound"):
+        if isinstance(instance_type, str):
+            msg = f"The instance type '{instance_type}' does not exist"
+        else:
+            msg = (
+                f"The following supplied instance types do not exist: "
+                f"[{', '.join(instance_type)}]"
+            )
+        super().__init__(error_type, msg)
 
 
 class InvalidAMIIdError(EC2ClientError):
@@ -427,8 +431,8 @@ class InvalidServiceName(EC2ClientError):
 
 
 class InvalidFilter(EC2ClientError):
-    def __init__(self, filter_name):
-        super().__init__("InvalidFilter", f"The filter '{filter_name}' is invalid")
+    def __init__(self, filter_name, error_type="InvalidFilter"):
+        super().__init__(error_type, f"The filter '{filter_name}' is invalid")
 
 
 class InvalidNextToken(EC2ClientError):
