@@ -76,6 +76,20 @@ class VPCEndPoint(TaggedEC2Resource, CloudFormationModel):
 
         self.created_at = utc_date_and_time()
 
+    def modify(self, policy_doc, add_subnets, add_route_tables, remove_route_tables):
+        if policy_doc:
+            self.policy_document = policy_doc
+        if add_subnets:
+            self.subnet_ids.extend(add_subnets)
+        if add_route_tables:
+            self.route_table_ids.extend(add_route_tables)
+        if remove_route_tables:
+            self.route_table_ids = [
+                rt_id
+                for rt_id in self.route_table_ids
+                if rt_id not in remove_route_tables
+            ]
+
     def get_filter_value(self, filter_name):
         if filter_name in ("vpc-endpoint-type", "vpc_endpoint_type"):
             return self.endpoint_type
@@ -593,6 +607,12 @@ class VPCBackend:
 
         return vpc_end_point
 
+    def modify_vpc_endpoint(
+        self, vpc_id, policy_doc, add_subnets, remove_route_tables, add_route_tables
+    ):
+        endpoint = self.describe_vpc_endpoints(vpc_end_point_ids=[vpc_id])[0]
+        endpoint.modify(policy_doc, add_subnets, add_route_tables, remove_route_tables)
+
     def delete_vpc_endpoints(self, vpce_ids=None):
         for vpce_id in vpce_ids or []:
             vpc_endpoint = self.vpc_end_points.get(vpce_id, None)
