@@ -1,4 +1,4 @@
-import random
+from moto.moto_api._internal import mock_random as random
 import string
 
 
