@@ -140,6 +140,15 @@ class GlueBackend(BaseBackend):
     def get_tables(self, database_name, expression):
         database = self.get_database(database_name)
         if expression:
+            # sanitise expression, * is treated as a glob-like wildcard
+            # so we make it a valid regex
+            if "*" in expression:
+                if expression.endswith(".*"):
+                    expression = (
+                        f"{expression[:-2].replace('*', '.*')}{expression[-2:]}"
+                    )
+                else:
+                    expression = expression.replace("*", ".*")
             return [
                 table
                 for table_name, table in database.tables.items()
