@@ -1,6 +1,6 @@
 import json
+from moto.core.exceptions import JsonRESTError
 from functools import wraps
-from werkzeug.exceptions import HTTPException
 
 
 def exception_handler(f):
@@ -14,10 +14,9 @@ def exception_handler(f):
     return _wrapper
 
 
-class ManagedBlockchainClientError(HTTPException):
-    code = 400
-
+class ManagedBlockchainClientError(JsonRESTError):
     def __init__(self, error_type, message):
+        super().__init__(error_type=error_type, message=message)
         self.error_type = error_type
         self.message = message
         self.description = json.dumps({"message": self.message})
@@ -28,10 +27,6 @@ class ManagedBlockchainClientError(HTTPException):
             ("x-amzn-ErrorType", self.error_type),
         ]
 
-    @property
-    def response(self):
-        return self.get_body()
-
     def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
         return self.description
 
