@@ -501,18 +501,13 @@ class ManagedBlockchainNode(BaseModel):
 
 
 class ManagedBlockchainBackend(BaseBackend):
-    def __init__(self, region_name):
+    def __init__(self, region_name, account_id):
+        super().__init__(region_name, account_id)
         self.networks = {}
         self.members = {}
         self.proposals = {}
         self.invitations = {}
         self.nodes = {}
-        self.region_name = region_name
-
-    def reset(self):
-        region_name = self.region_name
-        self.__dict__ = {}
-        self.__init__(region_name)
 
     def create_network(
         self,
