@@ -38,16 +38,10 @@ class Container(BaseModel):
 
 
 class MediaStoreBackend(BaseBackend):
-    def __init__(self, region_name=None):
-        super().__init__()
-        self.region_name = region_name
+    def __init__(self, region_name, account_id):
+        super().__init__(region_name, account_id)
         self._containers = OrderedDict()
 
-    def reset(self):
-        region_name = self.region_name
-        self.__dict__ = {}
-        self.__init__(region_name)
-
     def create_container(self, name, tags):
         arn = "arn:aws:mediastore:container:{}".format(name)
         container = Container(
