@@ -15,9 +15,12 @@ class SNSResponse(BaseResponse):
     )
     OPT_OUT_PHONE_NUMBER_REGEX = re.compile(r"^\+?\d+$")
 
+    def __init__(self):
+        super().__init__(service_name="sns")
+
     @property
     def backend(self):
-        return sns_backends[self.region]
+        return sns_backends[self.current_account][self.region]
 
     def _error(self, code, message, sender="Sender"):
         template = self.response_template(ERROR_RESPONSE)
@@ -410,7 +413,7 @@ class SNSResponse(BaseResponse):
         platform = self._get_param("Platform")
         attributes = self._get_attributes()
         platform_application = self.backend.create_platform_application(
-            self.region, name, platform, attributes
+            name, platform, attributes
         )
 
         if self.request_json:
@@ -525,7 +528,7 @@ class SNSResponse(BaseResponse):
         attributes = self._get_attributes()
 
         platform_endpoint = self.backend.create_platform_endpoint(
-            self.region, application, custom_user_data, token, attributes
+            application, custom_user_data, token, attributes
         )
 
         if self.request_json:
