@@ -14,12 +14,10 @@ from moto.utilities.utils import load_resource
 
 import datetime
 import time
-import uuid
 import json
 import yaml
 import hashlib
-import random
-
+from moto.moto_api._internal import mock_random as random
 from .utils import parameter_arn, convert_to_params
 from .exceptions import (
     ValidationException,
@@ -482,11 +480,6 @@ class Document(BaseModel):
         if document_format == "JSON":
             try:
                 content_json = json.loads(content)
-            except ValueError:
-                # Python2
-                raise InvalidDocumentContent(
-                    "The content for the document is not valid."
-                )
             except json.decoder.JSONDecodeError:
                 raise InvalidDocumentContent(
                     "The content for the document is not valid."
@@ -581,7 +574,7 @@ class Command(BaseModel):
         if targets is None:
             targets = []
 
-        self.command_id = str(uuid.uuid4())
+        self.command_id = str(random.uuid4())
         self.status = "Success"
         self.status_details = "Details placeholder"
         self.account_id = account_id
@@ -642,6 +635,7 @@ class Command(BaseModel):
             "CommandId": self.command_id,
             "Comment": self.comment,
             "CompletedCount": self.completed_count,
+            "DeliveryTimedOutCount": 0,
             "DocumentName": self.document_name,
             "ErrorCount": self.error_count,
             "ExpiresAfter": self.expires_after,
